@@ -143,6 +143,8 @@ ggv_file_sel_ok_clicked(GtkWidget *w, gpointer data)
         if(sel->uri)
                 g_free(sel->uri);
         sel->uri = ggv_file_sel_get_uri(sel);
+	if (sel->uri == NULL)
+		return;
         gtk_main_quit();
 }
 
