@@ -22,7 +22,6 @@ typedef struct _GtkGSDefaults
         gboolean   antialiased;
         gboolean   override_size;
         gint       default_size;
-	gboolean   watch_doc;
         gboolean   override_orientation;
         gboolean   respect_eof;
         gboolean   show_scroll_rect;
@@ -31,6 +30,7 @@ typedef struct _GtkGSDefaults
         gfloat     scroll_step;
         gchar      *interpreter_cmd;
         gchar      *alpha_params;
+        gchar      *dsc_cmd;
         gchar      *convert_pdf_cmd;
         gchar      *ungzip_cmd;
         gchar      *unbzip2_cmd;
@@ -38,8 +38,8 @@ typedef struct _GtkGSDefaults
 } GtkGSDefaults;
 
 static GtkGSDefaults gtk_gs_defaults = {
-        TRUE, FALSE, 8, TRUE, FALSE, TRUE, TRUE,
-        0, 1.0, 0.25, NULL, NULL, NULL, NULL, NULL,
+        TRUE, FALSE, 8, FALSE, TRUE, TRUE,
+        0, 1.0, 0.25, NULL, NULL, NULL, NULL, NULL, NULL,
         GTK_GS_ZOOM_ABSOLUTE
 };
 
@@ -71,20 +71,6 @@ gtk_gs_defaults_get_size()
         return gtk_gs_defaults.default_size;
 }
 
-void
-gtk_gs_defaults_set_watch_doc(gint iNewWatchDoc)
-{
-        gtk_gs_defaults.watch_doc = iNewWatchDoc;
-        gconf_client_set_bool(gconf_client, "/apps/ggv/gtkgs/watch_doc",
-                              gtk_gs_defaults_get_watch_doc(), NULL);
-}
-
-gint
-gtk_gs_defaults_get_watch_doc()
-{
-        return gtk_gs_defaults.watch_doc;
-}
-
 void
 gtk_gs_defaults_set_override_size(gboolean bOverrSize)
 {
@@ -234,6 +220,17 @@ gtk_gs_defaults_get_convert_pdf_cmd()
         return gtk_gs_defaults.convert_pdf_cmd;
 }
 
+const gchar *
+gtk_gs_defaults_get_dsc_cmd()
+{
+        if(!gtk_gs_defaults.dsc_cmd)
+                return GS_PATH
+                        " -q -dNODISPLAY -dSAFER -dDELAYSAFER"
+                        " -sDSCname=%s -sPDFname=%s pdf2dsc.ps"
+                        " -c quit";
+        return gtk_gs_defaults.dsc_cmd;
+}
+
 const gchar *
 gtk_gs_defaults_get_ungzip_cmd()
 {
@@ -280,6 +277,16 @@ gtk_gs_defaults_set_convert_pdf_cmd(gchar *cmd)
                                 gtk_gs_defaults_get_convert_pdf_cmd(), NULL);
 }
 
+void
+gtk_gs_defaults_set_dsc_cmd(gchar *cmd)
+{
+        if(gtk_gs_defaults.dsc_cmd)
+                g_free(gtk_gs_defaults.dsc_cmd);
+        gtk_gs_defaults.dsc_cmd = cmd;
+        gconf_client_set_string(gconf_client, "/apps/ggv/gtkgs/pdf2dsc",
+                                gtk_gs_defaults_get_dsc_cmd(), NULL);
+}
+
 void
 gtk_gs_defaults_set_ungzip_cmd(gchar *cmd)
 {
@@ -322,9 +329,6 @@ gtk_gs_defaults_load()
         gtk_gs_defaults.respect_eof =
                 (gconf_client_get_bool(gconf_client, "/apps/ggv/gtkgs/respect_eof",
                                        NULL));
-        gtk_gs_defaults.watch_doc =
-                (gconf_client_get_bool(gconf_client, "/apps/ggv/gtkgs/watch_doc",
-                                       NULL));
         gtk_gs_defaults.override_size =
                 (gconf_client_get_bool(gconf_client, "/apps/ggv/gtkgs/override_size",
                                        NULL));
@@ -352,6 +356,9 @@ gtk_gs_defaults_load()
         gtk_gs_defaults.convert_pdf_cmd =
                 (gconf_client_get_string(gconf_client, "/apps/ggv/gtkgs/convertpdf",
                                          NULL));
+        gtk_gs_defaults.dsc_cmd =
+                (gconf_client_get_string(gconf_client, "/apps/ggv/gtkgs/pdf2dsc",
+                                         NULL));
         gtk_gs_defaults.ungzip_cmd =
                 (gconf_client_get_string(gconf_client, "/apps/ggv/gtkgs/ungzip",
                                          NULL));
@@ -401,10 +408,6 @@ gtk_gs_defaults_changed(GConfClient* client, guint cnxn_id,
                 gtk_gs_defaults_set_override_size
                         (gconf_client_get_bool(client, "/apps/ggv/gtkgs/override_size",
                                                NULL));
-        else if(!strcmp(entry->key, "/apps/ggv/gtkgs/watch_doc"))
-                gtk_gs_defaults_set_watch_doc
-                        (gconf_client_get_bool(client, "/apps/ggv/gtkgs/watch_doc",
-                                               NULL));
         else if(!strcmp(entry->key, "/apps/ggv/gtkgs/show_scroll_rect"))
                 gtk_gs_defaults_set_show_scroll_rect
                         (gconf_client_get_bool(client, "/apps/ggv/gtkgs/show_scroll_rect",
@@ -421,6 +424,10 @@ gtk_gs_defaults_changed(GConfClient* client, guint cnxn_id,
                 gtk_gs_defaults_set_convert_pdf_cmd
                         (gconf_client_get_string(client, "/apps/ggv/gtkgs/convertpdf",
                                                  NULL));
+        else if(!strcmp(entry->key, "/apps/ggv/gtkgs/pdf2dsc"))
+                gtk_gs_defaults_set_dsc_cmd
+                        (gconf_client_get_string(client, "/apps/ggv/gtkgs/pdf2dsc",
+                                                 NULL));
         else if(!strcmp(entry->key, "/apps/ggv/gtkgs/ungzip"))
                 gtk_gs_defaults_set_ungzip_cmd
                         (gconf_client_get_string(client, "/apps/ggv/gtkgs/ungzip",
